@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.22'; 
+$VERSION = '0.23'; 
 
 use Carp qw(carp croak);
 use Errno qw(ETIMEDOUT ECONNRESET);
@@ -129,7 +129,7 @@ sub new {
 
        
         my $key = "";
-        for (1..16) { $key .= rand(9) }
+        for (1..16) { $key .= int(rand(9)) }
 
         $self->{session} = POE::Session->create(
                 package_states => [
